
/**
 * SampleDateTimeChooser.java
 */
import java.lang.*;
import java.util.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;

/**
 * Class:   SampleDateTimeChooser
 */
public class SampleDateTimeChooser extends SampleDateTimeChooser_Abstract
   {
    Locale locales[] = null;
    String days[] =
       {
        "Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"
       }; 

    String stylePattern[] =
        {
         "DateFormat FULL", "DateFormat LONG" ,
         "DateFormat MEDIUM", "DateFormat SHORT",
        };

    String types[] =
        {
         "Date only","Time only","Date and Time"
        };
    String timeZone[] =
        {
         "Local","Europe/Paris","America/Los_Angeles"
        };        
                       
    /**
     * Constructor: SampleDateTimeChooser
     * @return instance of SampleDateTimeChooser
     */
    public SampleDateTimeChooser()
       {
        super();
        get_StylePatternStringSpinButton().setStrings(stylePattern);
        get_StylePatternStringSpinButton().setValue(0);                 
        get_TypesStringSpinButton().setStrings(types);       
        get_TypesStringSpinButton().setValue(get_JbcDateTimeChooser().getChooserType());  
        Calendar calendar = Calendar.getInstance();
        locales = calendar.getAvailableLocales();
        String[] localeStrings = new String[locales.length];
        for (int i = 0; i < locales.length; i++ )
	     localeStrings[i] = locales[i].getDisplayName();
        get_LocaleStringSpinButton().setStrings(localeStrings);
        get_LocaleStringSpinButton().setString(Locale.getDefault().getDisplayName());  
        get_DaysStringSpinButton().setStrings(days);          
        get_DaysStringSpinButton().setValue(calendar.getFirstDayOfWeek()-1); 
        get_TimeZoneStringSpinButton().setStrings(timeZone); 
        get_TimeZoneStringSpinButton().setValue(0);         
       } /* End of Constructor: SampleDateTimeChooser */

    /**
     * Method: generalHandleException <br>
     * @param java.lang.Throwable exception
     * @return void
     */
    protected void generalHandleException(java.lang.Throwable exc)
       {
        /* Remove this comment and specialize processing here. */
        exc.printStackTrace(System.err);
       } /* End of Method: generalHandleException */

    /**
     * Method: main <br>
     * Note: Called only if we're an application. <br>
     * @param java.lang.String[] args the command line arguments
     * @return void
     */
    public static void main(java.lang.String[] args)
       {
        try
           {
            /* Set native look and feel */
            javax.swing.UIManager.setLookAndFeel(javax.swing.UIManager.getSystemLookAndFeelClassName());

            /* Creates new MainObject */
            SampleDateTimeChooser self = new SampleDateTimeChooser();
            /* Remove this comment and specialize processing here. */
            self.show();
           } /* End try */
        catch (java.lang.Throwable exc)
           {
            /* Remove this comment and specialize processing here. */
            exc.printStackTrace(System.err);
           } /* End catch */
       } /* End of Method: main */

    /**
     * Method: LocaleStringSpinButton_change_stateChanged <br>
     * Adapter: ChangeAdapter <br>
     * Interface: javax.swing.event.ChangeListener <br>
     * Note  : This method is called when the target of the listener
     *         has changed its state.  <br>
     * @param javax.swing.event.ChangeEvent evt
     * @return void
     */
    protected void LocaleStringSpinButton_change_stateChanged(javax.swing.event.ChangeEvent evt)
       {
        int index = get_LocaleStringSpinButton().getValue();
        if (locales != null && index >= 0 && index < locales.length)
           {
            get_JbcDateTimeChooser().setLocale(locales[index]);
            get_DaysStringSpinButton().setValue(get_JbcDateTimeChooser().getCalendar().getFirstDayOfWeek()-1);            
           }            
       } /* End of Method: LocaleStringSpinButton_change_stateChanged */

    /**
     * Method: DaysStringSpinButton_change_stateChanged <br>
     * Adapter: ChangeAdapter <br>
     * Interface: javax.swing.event.ChangeListener <br>
     * Note  : This method is called when the target of the listener
     *         has changed its state.  <br>
     * @param javax.swing.event.ChangeEvent evt
     * @return void
     */
    protected void DaysStringSpinButton_change_stateChanged(javax.swing.event.ChangeEvent evt)
       {
        Calendar calendar = get_JbcDateTimeChooser().getCalendar();
        int index = get_DaysStringSpinButton().getValue(); 
        calendar.setFirstDayOfWeek(index+1);      
        get_JbcDateTimeChooser().setCalendar(calendar);        
       } /* End of Method: DaysStringSpinButton_change_stateChanged */
       
    /**
     * Method: StylePatternStringSpinButton_change_stateChanged <br>
     * Adapter: ChangeAdapter <br>
     * Interface: javax.swing.event.ChangeListener <br>
     * Note  : This method is called when the target of the listener
     *         has changed its state.  <br>
     * @param javax.swing.event.ChangeEvent evt
     * @return void
     */
    protected void StylePatternStringSpinButton_change_stateChanged(javax.swing.event.ChangeEvent evt)
       {
        int index = get_StylePatternStringSpinButton().getValue();
        if (index != -1)
            get_JbcDateTimeChooser().setStylePattern(index);
       } /* End of Method: StylePatternStringSpinButton_change_stateChanged */

    /**
     * Method: TypesStringSpinButton_change_stateChanged <br>
     * Adapter: ChangeAdapter <br>
     * Interface: javax.swing.event.ChangeListener <br>
     * Note  : This method is called when the target of the listener
     *         has changed its state.  <br>
     * @param javax.swing.event.ChangeEvent evt
     * @return void
     */
    protected void TypesStringSpinButton_change_stateChanged(javax.swing.event.ChangeEvent evt)
       {
        int index = get_TypesStringSpinButton().getValue();
        if (index != -1)
            get_JbcDateTimeChooser().setChooserType(index);
       } /* End of Method: TypesStringSpinButton_change_stateChanged */

    /**
     * Method: TimeZoneStringSpinButton_change_stateChanged <br>
     * Adapter: ChangeAdapter <br>
     * Interface: javax.swing.event.ChangeListener <br>
     * Note  : This method is called when the target of the listener
     *         has changed its state.  <br>
     * @param javax.swing.event.ChangeEvent evt
     * @return void
     */
    protected void TimeZoneStringSpinButton_change_stateChanged(javax.swing.event.ChangeEvent evt)
       {
        TimeZone timeZone;
        int index = get_TimeZoneStringSpinButton().getValue();
        if (index == 0)
            timeZone = TimeZone.getDefault();
        else if (index == 1)
            timeZone = new SimpleTimeZone(3600000,"Europe/Paris");
        else
            timeZone = new SimpleTimeZone(-28800000,"America/Los_Angeles");
        Calendar aCalendar = get_JbcDateTimeChooser().getCalendar();
        aCalendar.setTimeZone(timeZone);
        get_JbcDateTimeChooser().setCalendar(aCalendar);           
       } /* End of Method: TimeZoneStringSpinButton_change_stateChanged */

   } /* End of Class: SampleDateTimeChooser */



