
/**
 * SampleTimeChooser.java
 */
import java.lang.*;
import java.util.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;

/**
 * Class:   SampleTimeChooser
 */
public class SampleTimeChooser extends SampleTimeChooser_Abstract
   {
    Locale locales[] = null;
    /**
     * Constructor: SampleTimeChooser
     * @return instance of SampleTimeChooser
     */
    public SampleTimeChooser()
       {
        super();
        Calendar calendar = Calendar.getInstance();
        locales = calendar.getAvailableLocales();
        String[] localeStrings = new String[locales.length];
        for (int i = 0; i < locales.length; i++ )
	     localeStrings[i] = locales[i].getDisplayName();
        get_LocaleStringSpinButton().setStrings(localeStrings);
        get_LocaleStringSpinButton().setString(Locale.getDefault().getDisplayName());         
       } /* End of Constructor: SampleTimeChooser */

    /**
     * Method: generalHandleException <br>
     * @param java.lang.Throwable exception
     * @return void
     */
    protected void generalHandleException(java.lang.Throwable exc)
       {
        exc.printStackTrace(System.err);
       } /* End of Method: generalHandleException */

    /**
     * Method: main <br>
     * Note: Called only if we're an application. <br>
     * @param java.lang.String[] args the command line arguments
     * @return void
     */
    public static void main(java.lang.String[] args)
       {
        try
           {
            /* Set native look and feel */
            javax.swing.UIManager.setLookAndFeel(javax.swing.UIManager.getSystemLookAndFeelClassName());

            /* Creates new MainObject */
            SampleTimeChooser self = new SampleTimeChooser();
            self.show();
           } /* End try */
        catch (java.lang.Throwable exc)
           {
            exc.printStackTrace(System.err);
           } /* End catch */
       } /* End of Method: main */

    /**
     * Method: JbcTimeChooser_change_stateChanged <br>
     * Adapter: ChangeAdapter <br>
     * Interface: javax.swing.event.ChangeListener <br>
     * Note  : This method is called when the target of the listener
     *         has changed its state.  <br>
     * @param javax.swing.event.ChangeEvent evt
     * @return void
     */
    protected void JbcTimeChooser_change_stateChanged(javax.swing.event.ChangeEvent evt)
       {
        Calendar calendar = get_JbcTimeChooser().getCalendar();
        int hour = calendar.get(Calendar.HOUR_OF_DAY);
        int minutes = calendar.get(Calendar.MINUTE);
        int seconds = calendar.get(Calendar.SECOND);
        get_Label().setText("" + hour + ":" + minutes + ":" + seconds);
        get_Label1().setText(get_JbcTimeChooser().getDate().toString());
       } /* End of Method: JbcTimeChooser_change_stateChanged */

    /**
     * Method: JCheckBoxAMPM_action_actionPerformed <br>
     * Adapter: ActionAdapter <br>
     * Interface: java.awt.event.ActionListener <br>
     * Note  : This method is called when an action occurs.  <br>
     * @param java.awt.event.ActionEvent evt
     * @return void
     */
    protected void JCheckBoxAMPM_action_actionPerformed(java.awt.event.ActionEvent evt)
       {
        get_JbcTimeChooser().setClockWithAmPm(get_JCheckBoxAMPM().isSelected());
       } /* End of Method: JCheckBoxAMPM_action_actionPerformed */

    /**
     * Method: LocaleStringSpinButton_change_stateChanged <br>
     * Adapter: ChangeAdapter <br>
     * Interface: javax.swing.event.ChangeListener <br>
     * Note  : This method is called when the target of the listener
     *         has changed its state.  <br>
     * @param javax.swing.event.ChangeEvent evt
     * @return void
     */
    protected void LocaleStringSpinButton_change_stateChanged(javax.swing.event.ChangeEvent evt)
       {
        int index = get_LocaleStringSpinButton().getValue();
        if (locales != null && index >= 0 && index < locales.length)
           {
            get_JbcTimeChooser().setLocale(locales[index]);
           } 
       } /* End of Method: LocaleStringSpinButton_change_stateChanged */

   } /* End of Class: SampleTimeChooser */



